| setOF | R Documentation |
This function will assign all flagged objects a single value returned as the objectFlag variable.
It is useful for collapsing many easyXpress OFs into a single flag label based on the order in which the flags were
added to the data frame.
setOF(data)
data |
A data frame with |
A single data frame with all flagged objects labelled in the objectFlag variable. All objects that are not flagged are
labelled noFlag.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.