| setWF | R Documentation |
This function will assign all flagged wells a single value returned as the wellFlag variable.
It is useful for collapsing many easyXpress WFs into a single flag label based on the order in which the flags were
added to the data frame.
setWF(data)
data |
A data frame with |
A single data frame with all flagged wells labelled in the wellFlag variable. All objects that are not flagged are
labelled noFlag.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.